@@ -9,8 +9,8 @@ django_keycloak_auth = importlib.import_module("django-keycloak-auth.keycloak")
 def token_decorator(func):
     @functools.wraps(func)
     def wrapper(kworker, *args, **kwargs):
-        if time.time() >= kworker.token_expiration:
-            if time.time() >= kworker.refresh_token_expiration:
+        if time.time() >= kworker.token_expiration - 5:
+            if time.time() >= kworker.refresh_token_expiration - 5:
                 kworker.get_token(auth_data=kworker.auth_data)
             else:
                 kworker.get_token(auth_data=kworker.auth_refresh_data)
@@ -41,7 +41,7 @@ class KeycloakWorker(django_keycloak_auth.KeycloakConnect):
     Groups:
       format: <IS name>_user_manage
       example: crux_user_manage
-      example: all:user:manage
+      example: all_user_manage
 
     Users:
       Keycloak is supposed to has a User Federation (LDAP catalog, AD)
